@@ -8,7 +8,6 @@ class KcrsClient(AbstractClient):
     _apiVersion = '2021-11-09'
     _endpoint = 'kcrs.api.ksyun.com'
     _service = 'kcrs'
-
     def CreateNamespace(self, request):
         """创建命名空间
         :param request: Request instance for CreateNamespace.
@@ -29,7 +28,8 @@ class KcrsClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def DescribeNamespace(self, request):
         """查询命名空间
@@ -51,7 +51,8 @@ class KcrsClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def ModifyNamespaceType(self, request):
         """修改命名空间类型
@@ -73,7 +74,8 @@ class KcrsClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def DescribeNamespaceExist(self, request):
         """查询命名空间是否存在
@@ -95,7 +97,8 @@ class KcrsClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def DeleteNamespace(self, request):
         """删除命名空间
@@ -117,10 +120,11 @@ class KcrsClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def DescribeImages(self, request):
-        """查询镜像
+        """用于查询镜像
         :param request: Request instance for DescribeImages.
         :type request: :class:`ksyun.client.kcrs.v20211109.models.DescribeImagesRequest`
         """
@@ -139,7 +143,8 @@ class KcrsClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def DeleteImages(self, request):
         """删除镜像
@@ -161,7 +166,8 @@ class KcrsClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def DeleteRepoTag(self, request):
         """删除tag
@@ -183,7 +189,8 @@ class KcrsClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def DescribeRepository(self, request):
         """查询仓库
@@ -205,7 +212,8 @@ class KcrsClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def ModifyRepoDesc(self, request):
         """修改仓库描述
@@ -227,7 +235,8 @@ class KcrsClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def DeleteRepository(self, request):
         """删除仓库
@@ -249,7 +258,8 @@ class KcrsClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def StartImageScan(self, request):
         """扫描镜像
@@ -271,7 +281,8 @@ class KcrsClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def DescribeImageScan(self, request):
         """查询镜像扫描
@@ -293,7 +304,8 @@ class KcrsClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def CreateInstanceToken(self, request):
         """创建凭证
@@ -315,7 +327,8 @@ class KcrsClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def DescribeInternalEndpoint(self, request):
         """DescribeInternalEndpoint
@@ -337,7 +350,8 @@ class KcrsClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def DescribeInstanceToken(self, request):
         """查询凭证
@@ -359,7 +373,8 @@ class KcrsClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def CreateInternalEndpoint(self, request):
         """CreateInternalEndpoint
@@ -381,7 +396,8 @@ class KcrsClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def ModifyInstanceTokenStatus(self, request):
         """开启/禁用凭证
@@ -403,7 +419,8 @@ class KcrsClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def DeleteInternalEndpoint(self, request):
         """DeleteInternalEndpoint
@@ -425,7 +442,8 @@ class KcrsClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def ModifyInstanceTokenInformation(self, request):
         """修改凭证信息
@@ -447,7 +465,8 @@ class KcrsClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def DescribeInternalEndpointDns(self, request):
         """DescribeInternalEndpointDns
@@ -469,7 +488,8 @@ class KcrsClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def DeleteInstanceToken(self, request):
         """删除凭证
@@ -491,7 +511,8 @@ class KcrsClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def CreateInternalEndpointDns(self, request):
         """CreateInternalEndpointDns
@@ -513,7 +534,8 @@ class KcrsClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def DeleteInternalEndpointDns(self, request):
         """DeleteInternalEndpointDns
@@ -535,7 +557,8 @@ class KcrsClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def CreateInstance(self, request):
         """创建仓库实例
@@ -557,16 +580,17 @@ class KcrsClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def DeleteInstance(self, request):
-        """删除实例
+        """删除企业版实例
         :param request: Request instance for DeleteInstance.
         :type request: :class:`ksyun.client.kcrs.v20211109.models.DeleteInstanceRequest`
         """
         try:
             params = request._serialize()
-            body = self.call_judge("DeleteInstance", params, "application/json")
+            body = self.call_judge("DeleteInstance", params, "application/x-www-form-urlencoded")
             response = json.loads(body)
             if "Error" not in response:
                 return body
@@ -579,7 +603,8 @@ class KcrsClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def DescribeInstanceUsage(self, request):
         """查询实例配额
@@ -601,7 +626,8 @@ class KcrsClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def DescribeInstance(self, request):
         """查询镜像实例信息
@@ -623,7 +649,8 @@ class KcrsClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def CreateWebhookTrigger(self, request):
         """创建触发器
@@ -645,7 +672,8 @@ class KcrsClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def DescribeWebhookTrigger(self, request):
         """查询触发器
@@ -667,7 +695,8 @@ class KcrsClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def ModifyWebhookTrigger(self, request):
         """修改触发器
@@ -689,7 +718,8 @@ class KcrsClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def DescribeWebhookTriggerLog(self, request):
         """查询触发器日志
@@ -711,7 +741,8 @@ class KcrsClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def DeleteWebhookTrigger(self, request):
         """删除触发器
@@ -733,7 +764,8 @@ class KcrsClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def CreateRetentionRule(self, request):
         """创建镜像清理规则
@@ -755,7 +787,8 @@ class KcrsClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def UpdateRetentionRule(self, request):
         """更新镜像清理规则
@@ -777,7 +810,8 @@ class KcrsClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def DeleteRetentionRule(self, request):
         """删除镜像清理规则
@@ -799,7 +833,8 @@ class KcrsClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def DescribeRetentionRule(self, request):
         """描述镜像清理规则
@@ -821,7 +856,8 @@ class KcrsClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def RunRetentionPolicy(self, request):
         """运行清理保留规则
@@ -843,7 +879,8 @@ class KcrsClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def GetRetentionPolicyLogs(self, request):
         """获取运行日志列表
@@ -865,7 +902,8 @@ class KcrsClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def GetRetentionPolicyLogDetail(self, request):
         """获取日志运行详情
@@ -887,7 +925,8 @@ class KcrsClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def GetRetentionPolicyLog(self, request):
         """获取日志保留结果
@@ -909,7 +948,8 @@ class KcrsClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def GetRetentionTrigger(self, request):
         """获取触发器
@@ -931,7 +971,8 @@ class KcrsClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def UpdateRetentionTrigger(self, request):
         """修改触发器
@@ -953,7 +994,8 @@ class KcrsClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
+
 
     def Schedule(self, request):
         """ks3清理
@@ -975,4 +1017,4 @@ class KcrsClient(AbstractClient):
             if isinstance(e, KsyunSDKException):
                 raise
             else:
-                raise KsyunSDKException(e.message, e.message)
+                raise KsyunSDKException(message=str(e))
