@@ -14,6 +14,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from __future__ import unicode_literals, print_function
 import copy
 import json
 import sys
@@ -21,6 +22,7 @@ import uuid
 import warnings
 import logging
 import logging.handlers
+import six
 
 try:
     from urllib.parse import urlencode
@@ -163,6 +165,11 @@ class AbstractClient(object):
             content_type = _x_protobuf
         req.header["Content-Type"] = content_type
 
+        # 支持自定义 header
+        if options.get("CustomHeaders"):
+            for key, value in options["CustomHeaders"].items():
+                req.header[key] = value
+
         # GET上传文件报错
         if req.method == "GET" and content_type == _multipart_content:
             raise SDKError("ClientError", "Invalid request method GET for multipart.")
@@ -206,9 +213,19 @@ class AbstractClient(object):
                 if isinstance(v, list) or isinstance(v, dict):
                     v = json.dumps(v)
                     body += b'Content-Type: application/json\r\n'
-            if sys.version_info[0] == 3 and isinstance(v, type("")):
-                v = v.encode()
-            body += b'\r\n%s\r\n' % v
+            # Python 2/3 compatible: convert any non-bytes value to bytes
+            if isinstance(v, six.binary_type):
+                # Already bytes
+                pass
+            elif isinstance(v, six.text_type):
+                # Unicode/str text -> bytes
+                v = v.encode('utf-8')
+            else:
+                # Numbers, None, etc. -> str -> bytes
+                v = str(v).encode('utf-8')
+            # Concatenate bytes
+            body += v
+            body += b'\r\n'
         if body != b'':
             body += b'--%s--\r\n' % boundary
         return body
@@ -229,7 +246,9 @@ class AbstractClient(object):
 
 
     def call(self, action, params, options=None):
-        req = RequestInternal(self._get_endpoint(), self.profile.httpProfile.reqMethod, self._requestPath)
+        # Use custom path from HttpProfile if available, otherwise use default _requestPath
+        request_path = self.profile.httpProfile.path if self.profile.httpProfile.path else self._requestPath
+        req = RequestInternal(self._get_endpoint(), self.profile.httpProfile.reqMethod, request_path)
         self._build_req_inter(action, params, req, options)
         resp_inter = self.request.send_request(req)
         self._check_status(resp_inter)
@@ -252,9 +271,11 @@ class AbstractClient(object):
         if self.profile.httpProfile.reqMethod != "POST":
             raise SDKError("ClientError", "Invalid request method.")
 
+        # Use custom path from HttpProfile if available, otherwise use default _requestPath
+        request_path = self.profile.httpProfile.path if self.profile.httpProfile.path else self._requestPath
         req = RequestInternal(self._get_endpoint(),
                               self.profile.httpProfile.reqMethod,
-                              self._requestPath)
+                              request_path)
         for key in headers:
             req.header[key] = headers[key]
         req.data = body
